@@ -1,7 +1,7 @@
 import pySPaRTAN.pl
 import pySPaRTAN.pp
 import pySPaRTAN.datasets
-import cythLeastR
-import cythKronPlus
+import pySPaRTAN.cythLeastR
+import pySPaRTAN.cythKronPlus
 from pySPaRTAN.pySPaRTAN import SPaRTAN
 
